@@ -36,7 +36,7 @@ class EmailPrincipal(Principal):
         self.email = str.lower(email)
 
     @ioc.inject('service', 'EmailService')
-    def send(self, service, subject, text, html=None, sender=None):
+    def send(self, service, subject, text, html=None, sender=None, **kwargs):
         return service.send(sender, subject, [self.email], text, html)
 
     def __str__(self):
