@@ -15,6 +15,7 @@
 # You should have received a copy of the GNU General Public License
 # along with python-iam.  If not, see <https://www.gnu.org/licenses/>.
 """Declares :class:`~PhonenumberPrincipal`."""
+import ioc
 import phonenumbers
 from phonenumbers import NumberParseException
 
@@ -42,5 +43,9 @@ class PhonenumberPrincipal(Principal):
         super().__init__()
         self.value = value
 
+    @ioc.inject('svc', 'TextMessageService')
+    def send(self, svc, text, sender=None, **kwargs):
+        return service.send(sender, [self.value], text)
+
     def __str__(self):
         return self.value or ''
