@@ -49,6 +49,7 @@ class PhonenumberBackend(LocalSubjectBackend):
     """An authentication backend that allows authentication using a phone
     number combined with a password, PIN or confirmation code.
     """
+    cache_lifetime = 3600
 
     def authenticate(self, request, realm, phonenumber, **kwargs):
         """Authenticate a :term:`Subject` using a phonenumber. If a confirmation
@@ -73,6 +74,7 @@ class PhonenumberBackend(LocalSubjectBackend):
         exists, it may be created.
         """
         # Get the challenge from the cache. Bail out if there is no challenge.
+        must_delete = False
         k = f'challenge:{value}'
         challenge = cache.get(k)
         if challenge is None:
@@ -83,13 +85,20 @@ class PhonenumberBackend(LocalSubjectBackend):
         try:
             is_valid = challenge.confirm(code)
             if is_valid:
-                cache.delete(k)
+                must_delete = True
         except challenge.MaximumAttemptsReached:
-            cache.delete(k)
+            must_delete = True
             is_valid = False
 
+        # Ensure that the code is deleted so it can not be reused.
+        if must_delete:
+            cache.delete(k)
+
         # Bail out if the provided code was not valid.
         if not is_valid:
+            # Update the cache with the new state.
+            if not must_delete:
+                cache.set(k, challenge, self.cache_lifetime)
             return None
 
         # Instantiate a Principal object from the provided keyword arguments
