@@ -7,6 +7,7 @@ from django.db import transaction
 class RegistrationService:
     """Provides an interface to register new :term:`Subjects`."""
     availability = ioc.class_property('PrincipalAvailabilityService')
+    PrincipalAssociated = type('PrincipalAssociated', (ValueError,), {})
 
     def register(self, host, platform, realm, principal, credentials=None):
         """Register a new :term:`Subject`, that is identified by the given
@@ -15,7 +16,7 @@ class RegistrationService:
         identifies the :term:`Subject`.
         """
         if not self.availability.isavailable(realm, principal):
-            raise ValueError(
+            raise self.PrincipalAssociated(
                 f"{principal.kind}:{principal.value} is already associated.")
         Subject = apps.get_model('iam.Subject')
         SubjectRegistration = apps.get_model('iam.SubjectRegistration')
