@@ -58,10 +58,10 @@ class IAMContextMixin:
             'iam_enable_local': self.allow_local\
                 and bool(settings.IAM_ACCOUNT_PRINCIPALS),
             'iam_enable_magic_link': settings.IAM_ENABLE_MAGIC_LINK,
-            'iam_enable_password_reset': settings.IAM_ENABLE_PASSWORD_RESET,
+            'iam_enable_password_reset': self.can_reset_password(),
             'iam_image_logo': settings.IAM_IMAGE_LOGO,
             'iam_principals_placeholder': self.get_principal_placeholder(),
-            'iam_public_realm': self.allow_public,
+            'iam_public_realm': self.is_public_realm(),
             'iam_redirect_field_name': self.redirect_field_name,
             'iam_require_username': settings.IAM_REQUIRE_USERNAME,
         })
@@ -100,3 +100,16 @@ class IAMContextMixin:
     def get_realm(self):
         """Returns the :term:`Realm` for this controller."""
         return self.realm
+
+    def can_reset_password(self):
+        """Return a boolean indicating if a :term:`Subject` can reset its
+        password through this controller.
+        """
+        return settings.IAM_ENABLE_PASSWORD_RESET and self.is_public_realm()
+
+    def is_public_realm(self):
+        """Return a boolean indicating if the realm that is configured for
+        this controller is public.
+        """
+        config = settings.IAM_REALM_SETTINGS.get(self.realm) or {}
+        return bool(config.get('public')) and self.allow_public
